@@ -6,7 +6,7 @@ warnings.simplefilter("ignore", FITSFixedWarning)
 from . import config
 
 CONFIG = config.ConfigManager()
-
+CONFIG.check_builtins_changes()
 
 from . import visualization as viz
 
@@ -14,7 +14,7 @@ from .io.fitsmanager import FitsManager
 from .fluxes import ApertureFluxes
 from .telescope import Telescope
 from .block import Block
-from .sequence import Sequence, MultiProcessSequence
+from .sequence import Sequence
 from .image import Image
 from .observation import Observation
 from .observations import Observations
