@@ -57,10 +57,11 @@ class Observation(ApertureFluxes):
         self.tic_data = None
         self._meridian_flip = None
 
-        self._check_stack()
-        self._stack = Image(data=self.x["stack"].values, header=clean_header(self.x.attrs))
-        if "stars" in self.x:
-            self.stack.stars_coords = self.x.stars.values
+        if self.has_stack:
+            self._stack = Image(data=self.x["stack"].values, header=clean_header(self.x.attrs))
+
+            if "stars" in self.x:
+                self.stack.stars_coords = self.x.stars.values
 
         has_bjd = hasattr(self.xarray, "bjd_tdb")
         if has_bjd:
@@ -75,8 +76,12 @@ class Observation(ApertureFluxes):
                 if not time_verbose:
                     print(f"{INFO_LABEL} Could not convert time to BJD TDB")
 
-    def _check_stack(self):
-        assert 'stack' in self.xarray is not None, "No stack found"
+    @property
+    def has_stack(self):
+        return 'stack' in self.xarray is not None
+
+    def assert_stack(self):
+        assert self.has_stack, "This observation has no stack image"
 
     # Loaders and savers (files and data)
     # ------------------------------------
@@ -84,7 +89,8 @@ class Observation(ApertureFluxes):
         copied = Observation(self.xarray.copy(), time_verbose=True)
         copied.phot = self.phot
         copied.telescope = self.telescope
-        copied.stack.wcs = self.wcs
+        if self.has_stack:
+            copied.stack.wcs = self.wcs
 
         return copied
 
@@ -131,7 +137,7 @@ class Observation(ApertureFluxes):
         destination = self.phot if destination is None else destination
         self.xarray.attrs.update(self.stack.header)
         self.xarray.to_netcdf(destination)
-        info(f"saved {Path(destination).absolute}")
+        info(f"saved {str(Path(destination).absolute())}")
 
     # Convenience
     # -----------
@@ -215,14 +221,6 @@ class Observation(ApertureFluxes):
     def night_date(self):
         return self.stack.night_date
 
-    @property
-    def target(self):
-        return int(self.x.attrs['target'])
-
-    @target.setter
-    def target(self, i):
-        self.x.attrs["target"] = i
-
     # TESS specific methods
     # --------------------
     
@@ -282,7 +280,6 @@ class Observation(ApertureFluxes):
             by default "prose"
         """
         assert self.telescope is not None
-        assert self.skycoord is not None
 
         exposure_days = self.xarray.exposure.values/60/60/24
 
@@ -298,11 +295,11 @@ class Observation(ApertureFluxes):
 
         if version == "prose":
             time = Time(self.jd_utc + exposure_days/2, format="jd", scale="utc", location=self.telescope.earth_location).tdb
-            light_travel_tbd = time.light_travel_time(self.skycoord, location=self.telescope.earth_location)
+            light_travel_tbd = time.light_travel_time(self.stack.skycoord, location=self.telescope.earth_location)
             bjd_time = (time + light_travel_tbd).value
 
         elif version == "eastman":
-            bjd_time = utils.jd_to_bjd(self.jd_utc + exposure_days/2, self.skycoord.ra.deg, self.skycoord.dec.deg)
+            bjd_time = utils.jd_to_bjd(self.jd_utc + exposure_days/2, self.stack.skycoord.ra.deg, self.skycoord.dec.deg)
 
         self.xarray = self.xarray.assign_coords(time=bjd_time)
         self.xarray["bjd_tdb"] = ("time", bjd_time)
@@ -434,6 +431,8 @@ class Observation(ApertureFluxes):
             obs.plot_psf_model()
             
         """
+
+        self.assert_stack()
         
         # Extracting and computing PSF model
         # ---------------------------------    
@@ -687,12 +686,14 @@ class Observation(ApertureFluxes):
 
         """
 
+        self.assert_stack()
+
         if isinstance(star, (tuple, list, np.ndarray)):
             x, y = star
         else:
             if star is None:
                 star = self.target
-            assert isinstance(star, int), "star must be star coordinates or integer index"
+            assert isinstance(star, (np.integer, int)), "star must be star coordinates or integer index"
 
             x, y = self.stars[star]
 
@@ -841,6 +842,8 @@ class Observation(ApertureFluxes):
             
 
         """
+        self.assert_stack()
+
         self.stack.show(stars=False)
         
         if stars is None:
@@ -1044,7 +1047,7 @@ class Observation(ApertureFluxes):
         display(HTML(widget))
 
     def plate_solve(self):
-        """Plate solve the current py::stack``
+        """Plate solve the current py::stack
         """
         self.stack = blocks.catalogs.PlateSolve()(self.stack)   
 
